%--------------------------------------------------------------------
%
% function boxmean
%
% fast boxmean of large matrices
%
% computes mean-values of input matrix X over blocksizes red_fac x red_fac
% and returns the down-sampled output matrix Y
%
% Example X        =  4000x6000 input matrix
%         red_fac  = 5
%         
%         --> computes mean-values over 5x5 blocks 
%
%         Y        = 800 x1200 output matrix
%
% Purpose: reduction of 30 sec SRTM to 120 sec resolution
% CH 2012-06-01
% 
%--------------------------------------------------------------------

function Y = boxmean(X,red_fac)

% dimensions of the input matrix
[n1 m1] = size(X)

% dimensions of the output matrix
n2=n1/red_fac
m2=m1/red_fac

% Compute partitions
partition_n =red_fac*ones(1,n2);
partition_m =red_fac*ones(1,m2);

% Partition the matrix in blocks of size red_fac
Xcell=mat2cell(X,partition_n,partition_m);
clear X partition*

% Rearrange the partitions
XX=horzcat(Xcell{:}); 
% ok bis hier

b =reshape(XX,[],n2*m2);
Means=mean( b ,1);

Y = reshape(Means,n2,m2);
 